pub struct Interrupt {
pub node_id: String,
pub tool_call_id: String,
pub questions: Vec<Question>,
pub interactions: Vec<HumanInteraction>,
pub message_id: i64,
pub chat_id: i64,
}Expand description
Present when a conversation run is interrupted, waiting for
crate::AgentContext::continue_conversation
Fields
node_id: StringID of the node that triggered the interrupt
tool_call_id: StringTool call ID of this inquiry; used as the answer key when continuing
questions: Vec<Question>Questions you need to answer
interactions: Vec<HumanInteraction>Full interaction descriptors used to render and answer the pause.
message_id: i64ID of the paused message
chat_id: i64ID of the owning conversation