#[repr(i32)]pub enum TradeStatus {
Normal = 0,
Halted = 1,
Delisted = 2,
Fuse = 3,
PrepareList = 4,
CodeMoved = 5,
ToBeOpened = 6,
SplitStockHalts = 7,
Expired = 8,
WarrantPrepareList = 9,
SuspendTrade = 10,
}Variants
Normal = 0
Halted = 1
Delisted = 2
Fuse = 3
PrepareList = 4
CodeMoved = 5
ToBeOpened = 6
SplitStockHalts = 7
Expired = 8
WarrantPrepareList = 9
SuspendTrade = 10
Implementations
Sourceimpl TradeStatus
impl TradeStatus
Sourceimpl TradeStatus
impl TradeStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<TradeStatus>
pub fn from_str_name(value: &str) -> Option<TradeStatus>
Creates an enum from field names used in the ProtoBuf definition.