pub struct SecurityCalcIndex {Show 41 fields
pub symbol: String,
pub last_done: Option<Decimal>,
pub change_value: Option<Decimal>,
pub change_rate: Option<Decimal>,
pub volume: Option<i64>,
pub turnover: Option<Decimal>,
pub ytd_change_rate: Option<Decimal>,
pub turnover_rate: Option<Decimal>,
pub total_market_value: Option<Decimal>,
pub capital_flow: Option<Decimal>,
pub amplitude: Option<Decimal>,
pub volume_ratio: Option<Decimal>,
pub pe_ttm_ratio: Option<Decimal>,
pub pb_ratio: Option<Decimal>,
pub dividend_ratio_ttm: Option<Decimal>,
pub five_day_change_rate: Option<Decimal>,
pub ten_day_change_rate: Option<Decimal>,
pub half_year_change_rate: Option<Decimal>,
pub five_minutes_change_rate: Option<Decimal>,
pub expiry_date: Option<Date>,
pub strike_price: Option<Decimal>,
pub upper_strike_price: Option<Decimal>,
pub lower_strike_price: Option<Decimal>,
pub outstanding_qty: Option<i64>,
pub outstanding_ratio: Option<Decimal>,
pub premium: Option<Decimal>,
pub itm_otm: Option<Decimal>,
pub implied_volatility: Option<Decimal>,
pub warrant_delta: Option<Decimal>,
pub call_price: Option<Decimal>,
pub to_call_price: Option<Decimal>,
pub effective_leverage: Option<Decimal>,
pub leverage_ratio: Option<Decimal>,
pub conversion_ratio: Option<Decimal>,
pub balance_point: Option<Decimal>,
pub open_interest: Option<i64>,
pub delta: Option<Decimal>,
pub gamma: Option<Decimal>,
pub theta: Option<Decimal>,
pub vega: Option<Decimal>,
pub rho: Option<Decimal>,
}Expand description
Security calc index response
Fields
symbol: StringSecurity code
last_done: Option<Decimal>Latest price
change_value: Option<Decimal>Change value
change_rate: Option<Decimal>Change ratio
volume: Option<i64>Volume
turnover: Option<Decimal>Turnover
ytd_change_rate: Option<Decimal>Year-to-date change ratio
turnover_rate: Option<Decimal>Turnover rate
total_market_value: Option<Decimal>Total market value
capital_flow: Option<Decimal>Capital flow
amplitude: Option<Decimal>Amplitude
volume_ratio: Option<Decimal>Volume ratio
pe_ttm_ratio: Option<Decimal>PE (TTM)
pb_ratio: Option<Decimal>PB
dividend_ratio_ttm: Option<Decimal>Dividend ratio (TTM)
five_day_change_rate: Option<Decimal>Five days change ratio
ten_day_change_rate: Option<Decimal>Ten days change ratio
half_year_change_rate: Option<Decimal>Half year change ratio
five_minutes_change_rate: Option<Decimal>Five minutes change ratio
expiry_date: Option<Date>Expiry date
strike_price: Option<Decimal>Strike price
upper_strike_price: Option<Decimal>Upper bound price
lower_strike_price: Option<Decimal>Lower bound price
outstanding_qty: Option<i64>Outstanding quantity
outstanding_ratio: Option<Decimal>Outstanding ratio
Premium
itm_otm: Option<Decimal>In/out of the bound
implied_volatility: Option<Decimal>Implied volatility
warrant_delta: Option<Decimal>Warrant delta
call_price: Option<Decimal>Call price
to_call_price: Option<Decimal>Price interval from the call price
effective_leverage: Option<Decimal>Effective leverage
leverage_ratio: Option<Decimal>Leverage ratio
conversion_ratio: Option<Decimal>Conversion ratio
balance_point: Option<Decimal>Breakeven point
open_interest: Option<i64>Open interest
delta: Option<Decimal>Delta. Measures the expected change in option price for a $1 move in the underlying asset price.
gamma: Option<Decimal>Gamma. Measures the expected change in Delta for a $1 move in the underlying asset price.
theta: Option<Decimal>Theta. Measures the expected change in option price as one day passes; the raw value has been divided by 365 to convert to a daily value, representing the impact of one day’s time decay on the option price.
vega: Option<Decimal>Vega. Measures the expected change in option price when implied volatility (IV) moves by 1 (i.e. 100%); divide the raw value by 100 to get the expected price change per 1% move in IV.
rho: Option<Decimal>Rho. Measures the expected change in option price when the risk-free interest rate moves by 1 (i.e. 100%); divide the raw value by 100 to get the expected price change per 1% move in the interest rate.