pub struct ScreenerIndicatorsResponse {
pub data: Value,
}Expand description
Response for crate::ScreenerContext::screener_indicators
The raw data contains all available screener indicator definitions. The exact structure varies so the payload is preserved as raw JSON.
Fields
data: ValueRaw indicator definitions