pub struct ScreenerRecommendStrategiesResponse {
pub data: Value,
}Expand description
Response for crate::ScreenerContext::screener_recommend_strategies
The raw data contains a list of recommended built-in screener strategies. The exact structure varies so the payload is preserved as raw JSON.
Fields
data: ValueRaw recommended strategies data