pub struct ScreenerSearchResponse {
pub data: Value,
}Expand description
Response for crate::ScreenerContext::screener_search
The raw data contains a page of screened security results. The exact structure varies so the payload is preserved as raw JSON.
Fields
data: ValueRaw screener search results