pub struct ScreenerStrategyResponse {
pub data: Value,
}Expand description
Response for crate::ScreenerContext::screener_strategy
The raw data contains detail for one screener strategy. The exact structure varies so the payload is preserved as raw JSON.
Fields
data: ValueRaw strategy detail data