pub struct PushGridOrderChanged {Show 15 fields
pub order_id: String,
pub status: String,
pub symbol: String,
pub suspend_reason: String,
pub submitted_base_price: String,
pub current_base_price: String,
pub upper_limit_price: String,
pub lower_limit_price: String,
pub trigger_price_type: i32,
pub trigger_quantity: String,
pub settlement_currency: String,
pub time_in_force: i32,
pub rth: i32,
pub grid_order_type_up: String,
pub grid_order_type_down: String,
}Expand description
Grid trading master-order changed message.
Delivered on the same private topic as regular order changes. Field set is
a skeleton to be confirmed against the test environment during integration;
unknown fields are ignored (#[serde(default)]).
Fields
order_id: StringGrid master order ID
status: StringOrder status
symbol: StringSecurity symbol (e.g. 700.HK)
suspend_reason: StringSuspend reason, if any
submitted_base_price: StringSubmitted base price
current_base_price: StringCurrent base price
upper_limit_price: StringUpper price bound
lower_limit_price: StringLower price bound
trigger_price_type: i32Trigger price type
trigger_quantity: StringQuantity per trigger
settlement_currency: StringSettlement currency
time_in_force: i32Time in force (0 = Day, 1 = GTC, 6 = GTD)
rth: i32Regular trading hours flag
grid_order_type_up: StringSell-side order type when depth is 0
grid_order_type_down: StringBuy-side order type when depth is 0