AnswersByToolCall

Type Alias AnswersByToolCall 

pub type AnswersByToolCall = HashMap<String, HashMap<String, String>>;
Answers keyed by tool_call_id, each value being a map of question text to answer, used as the request body of crate::AgentContext::continue_conversation and crate::AgentContext::continue_conversation_streamed.

Aliased Type

pub struct AnswersByToolCall { /* private fields */ }